@@ -5,10 +5,11 @@
 */
 
 #include "mobileproviders.h"
-#include "debug.h"
+#include "plasma_nm_editor.h"
 
 #include <QFile>
 #include <QLocale>
+#include <QRegularExpression>
 #include <QTextStream>
 
 const QString MobileProviders::ProvidersFile = QStringLiteral(BROADBANDPROVIDER_DATABASE);
@@ -45,19 +46,19 @@ MobileProviders::MobileProviders()
             docElement = mDocProviders.documentElement();
 
             if (docElement.isNull()) {
-                qCWarning(PLASMA_NM) << ProvidersFile << ": document is null";
+                qCWarning(PLASMA_NM_EDITOR_LOG) << ProvidersFile << ": document is null";
                 mError = ProvidersIsNull;
             } else {
-                if (docElement.isNull() || docElement.tagName() != "serviceproviders") {
-                    qCWarning(PLASMA_NM) << ProvidersFile << ": wrong format";
+                if (docElement.isNull() || docElement.tagName() != QLatin1String("serviceproviders")) {
+                    qCWarning(PLASMA_NM_EDITOR_LOG) << ProvidersFile << ": wrong format";
                     mError = ProvidersWrongFormat;
                 } else {
-                    if (docElement.attribute("format") != "2.0") {
-                        qCWarning(PLASMA_NM) << ProvidersFile << ": mobile broadband provider database format '" << docElement.attribute("format")
-                                             << "' not supported.";
+                    if (docElement.attribute(QStringLiteral("format")) != QLatin1String("2.0")) {
+                        qCWarning(PLASMA_NM_EDITOR_LOG) << ProvidersFile << ": mobile broadband provider database format '"
+                                                        << docElement.attribute(QStringLiteral("format")) << "' not supported.";
                         mError = ProvidersFormatNotSupported;
                     } else {
-                        // qCDebug(PLASMA_NM) << "Everything is alright so far";
+                        // qCDebug(PLASMA_NM_EDITOR_LOG) << "Everything is alright so far";
                     }
                 }
             }
@@ -65,14 +66,12 @@ MobileProviders::MobileProviders()
 
         file2.close();
     } else {
-        qCWarning(PLASMA_NM) << "Error opening providers file" << ProvidersFile;
+        qCWarning(PLASMA_NM_EDITOR_LOG) << "Error opening providers file" << ProvidersFile;
         mError = ProvidersMissing;
     }
 }
 
-MobileProviders::~MobileProviders()
-{
-}
+MobileProviders::~MobileProviders() = default;
 
 QStringList MobileProviders::getCountryList() const
 {
@@ -88,7 +87,7 @@ QString MobileProviders::countryFromLocale() const
     if (idx != -1) {
         return localeName.mid(idx + 1);
     }
-    return QString();
+    return {};
 }
 
 QStringList MobileProviders::getProvidersList(QString country, NetworkManager::ConnectionSettings::ConnectionType type)
@@ -106,12 +105,12 @@ QStringList MobileProviders::getProvidersList(QString country, NetworkManager::C
     while (!n.isNull()) {
         QDomElement e = n.toElement(); // <country ...>
 
-        if (!e.isNull() && e.attribute("code").toUpper() == country) {
+        if (!e.isNull() && e.attribute(QStringLiteral("code")).toUpper() == country) {
             QDomNode n2 = e.firstChild();
             while (!n2.isNull()) {
                 QDomElement e2 = n2.toElement(); // <provider ...>
 
-                if (!e2.isNull() && e2.tagName().toLower() == "provider") {
+                if (!e2.isNull() && e2.tagName().toLower() == QLatin1String("provider")) {
                     QDomNode n3 = e2.firstChild();
                     bool hasGsm = false;
                     bool hasCdma = false;
@@ -121,17 +120,17 @@ QStringList MobileProviders::getProvidersList(QString country, NetworkManager::C
                         QDomElement e3 = n3.toElement(); // <name | gsm | cdma>
 
                         if (!e3.isNull()) {
-                            if (e3.tagName().toLower() == "gsm") {
+                            if (e3.tagName().toLower() == QLatin1String("gsm")) {
                                 hasGsm = true;
-                            } else if (e3.tagName().toLower() == "cdma") {
+                            } else if (e3.tagName().toLower() == QLatin1String("cdma")) {
                                 hasCdma = true;
-                            } else if (e3.tagName().toLower() == "name") {
-                                QString lang = e3.attribute("xml:lang");
+                            } else if (e3.tagName().toLower() == QLatin1String("name")) {
+                                QString lang = e3.attribute(QStringLiteral("xml:lang"));
                                 if (lang.isEmpty()) {
-                                    lang = "en"; // English is default
+                                    lang = QStringLiteral("en"); // English is default
                                 } else {
                                     lang = lang.toLower();
-                                    lang.remove(QRegExp("\\-.*$")); // Remove everything after '-' in xml:lang attribute.
+                                    lang.remove(QRegularExpression(QStringLiteral("\\-.*$"))); // Remove everything after '-' in xml:lang attribute.
                                 }
                                 localizedProviderNames.insert(lang, e3.text());
                             }
@@ -166,7 +165,7 @@ QStringList MobileProviders::getApns(const QString &provider)
     mApns.clear();
     mNetworkIds.clear();
     if (!mProvidersGsm.contains(provider)) {
-        return QStringList();
+        return {};
     }
 
     QDomNode n = mProvidersGsm[provider];
@@ -174,29 +173,29 @@ QStringList MobileProviders::getApns(const QString &provider)
     while (!n.isNull()) {
         QDomElement e = n.toElement(); // <gsm | cdma>
 
-        if (!e.isNull() && e.tagName().toLower() == "gsm") {
+        if (!e.isNull() && e.tagName().toLower() == QLatin1String("gsm")) {
             QDomNode n2 = e.firstChild();
             while (!n2.isNull()) {
                 QDomElement e2 = n2.toElement(); // <apn | network-id>
 
-                if (!e2.isNull() && e2.tagName().toLower() == "apn") {
+                if (!e2.isNull() && e2.tagName().toLower() == QLatin1String("apn")) {
                     bool isInternet = true;
                     QDomNode n3 = e2.firstChild();
                     while (!n3.isNull()) {
                         QDomElement e3 = n3.toElement(); // <usage>
-                        if (!e3.isNull() && e3.tagName().toLower() == "usage" && !e3.attribute("type").isNull()
-                            && e3.attribute("type").toLower() != "internet") {
-                            // qCDebug(PLASMA_NM) << "apn" << e2.attribute("value") << "ignored because of usage" << e3.attribute("type");
+                        if (!e3.isNull() && e3.tagName().toLower() == QLatin1String("usage") && !e3.attribute(QStringLiteral("type")).isNull()
+                            && e3.attribute(QStringLiteral("type")).toLower() != QLatin1String("internet")) {
+                            // qCDebug(PLASMA_NM_EDITOR_LOG) << "apn" << e2.attribute("value") << "ignored because of usage" << e3.attribute("type");
                             isInternet = false;
                             break;
                         }
                         n3 = n3.nextSibling();
                     }
                     if (isInternet) {
-                        mApns.insert(e2.attribute("value"), e2.firstChild());
+                        mApns.insert(e2.attribute(QStringLiteral("value")), e2.firstChild());
                     }
-                } else if (!e2.isNull() && e2.tagName().toLower() == "network-id") {
-                    mNetworkIds.append(e2.attribute("mcc") + '-' + e2.attribute("mnc"));
+                } else if (!e2.isNull() && e2.tagName().toLower() == QLatin1String("network-id")) {
+                    mNetworkIds.append(e2.attribute(QStringLiteral("mcc")) + '-' + e2.attribute(QStringLiteral("mnc")));
                 }
 
                 n2 = n2.nextSibling();
@@ -228,17 +227,17 @@ ProviderData MobileProviders::parseProvider(const QDomNode &providerNode)
                 QDomElement gsmElement = gsmNode.toElement();
 
                 if (gsmElement.tagName().toLower() == QLatin1String("network-id")) {
-                    result.mccmncs.append(gsmElement.attribute("mcc") + gsmElement.attribute("mnc"));
+                    result.mccmncs.append(gsmElement.attribute(QStringLiteral("mcc")) + gsmElement.attribute(QStringLiteral("mnc")));
                 }
                 gsmNode = gsmNode.nextSibling();
             }
         } else if (ce.tagName().toLower() == QLatin1String("name")) {
-            QString lang = ce.attribute("xml:lang");
+            QString lang = ce.attribute(QStringLiteral("xml:lang"));
             if (lang.isEmpty()) {
-                lang = "en"; // English is default
+                lang = QStringLiteral("en"); // English is default
             } else {
                 lang = lang.toLower();
-                lang.remove(QRegExp("\\-.*$")); // Remove everything after '-' in xml:lang attribute.
+                lang.remove(QRegularExpression(QStringLiteral("\\-.*$"))); // Remove everything after '-' in xml:lang attribute.
             }
             localizedProviderNames.insert(lang, ce.text());
         }
@@ -264,7 +263,7 @@ QStringList MobileProviders::getProvidersFromMCCMNC(const QString &targetMccMnc)
             while (!n2.isNull()) {
                 QDomElement e2 = n2.toElement(); // <provider ...>
 
-                if (!e2.isNull() && e2.tagName().toLower() == "provider") {
+                if (!e2.isNull() && e2.tagName().toLower() == QLatin1String("provider")) {
                     ProviderData data = parseProvider(e2);
 
                     if (data.mccmncs.contains(targetMccMnc)) {
@@ -299,20 +298,20 @@ QVariantMap MobileProviders::getApnInfo(const QString &apn)
         QDomElement e = n.toElement(); // <name|username|password|dns(*)>
 
         if (!e.isNull()) {
-            if (e.tagName().toLower() == "name") {
-                QString lang = e.attribute("xml:lang");
+            if (e.tagName().toLower() == QLatin1String("name")) {
+                QString lang = e.attribute(QStringLiteral("xml:lang"));
                 if (lang.isEmpty()) {
-                    lang = "en"; // English is default
+                    lang = QStringLiteral("en"); // English is default
                 } else {
                     lang = lang.toLower();
-                    lang.remove(QRegExp("\\-.*$")); // Remove everything after '-' in xml:lang attribute.
+                    lang.remove(QRegularExpression(QStringLiteral("\\-.*$"))); // Remove everything after '-' in xml:lang attribute.
                 }
                 localizedPlanNames.insert(lang, e.text());
-            } else if (e.tagName().toLower() == "username") {
-                temp.insert("username", e.text());
-            } else if (e.tagName().toLower() == "password") {
-                temp.insert("password", e.text());
-            } else if (e.tagName().toLower() == "dns") {
+            } else if (e.tagName().toLower() == QLatin1String("username")) {
+                temp.insert(QStringLiteral("username"), e.text());
+            } else if (e.tagName().toLower() == QLatin1String("password")) {
+                temp.insert(QStringLiteral("password"), e.text());
+            } else if (e.tagName().toLower() == QLatin1String("dns")) {
                 dnsList.append(e.text());
             }
         }
@@ -322,11 +321,11 @@ QVariantMap MobileProviders::getApnInfo(const QString &apn)
 
     QString name = getNameByLocale(localizedPlanNames);
     if (!name.isEmpty()) {
-        temp.insert("name", QVariant::fromValue(name));
+        temp.insert(QStringLiteral("name"), QVariant::fromValue(name));
     }
-    temp.insert("number", getGsmNumber());
-    temp.insert("apn", apn);
-    temp.insert("dnsList", dnsList);
+    temp.insert(QStringLiteral("number"), getGsmNumber());
+    temp.insert(QStringLiteral("apn"), apn);
+    temp.insert(QStringLiteral("dnsList"), dnsList);
 
     return temp;
 }
@@ -334,7 +333,7 @@ QVariantMap MobileProviders::getApnInfo(const QString &apn)
 QVariantMap MobileProviders::getCdmaInfo(const QString &provider)
 {
     if (!mProvidersCdma.contains(provider)) {
-        return QVariantMap();
+        return {};
     }
 
     QVariantMap temp;
@@ -344,17 +343,17 @@ QVariantMap MobileProviders::getCdmaInfo(const QString &provider)
     while (!n.isNull()) {
         QDomElement e = n.toElement(); // <gsm or cdma ...>
 
-        if (!e.isNull() && e.tagName().toLower() == "cdma") {
+        if (!e.isNull() && e.tagName().toLower() == QLatin1String("cdma")) {
             QDomNode n2 = e.firstChild();
             while (!n2.isNull()) {
                 QDomElement e2 = n2.toElement(); // <name | username | password | sid>
 
                 if (!e2.isNull()) {
-                    if (e2.tagName().toLower() == "username") {
-                        temp.insert("username", e2.text());
-                    } else if (e2.tagName().toLower() == "password") {
-                        temp.insert("password", e2.text());
-                    } else if (e2.tagName().toLower() == "sid") {
+                    if (e2.tagName().toLower() == QLatin1String("username")) {
+                        temp.insert(QStringLiteral("username"), e2.text());
+                    } else if (e2.tagName().toLower() == QLatin1String("password")) {
+                        temp.insert(QStringLiteral("password"), e2.text());
+                    } else if (e2.tagName().toLower() == QLatin1String("sid")) {
                         sidList.append(e2.text());
                     }
                 }
@@ -365,8 +364,8 @@ QVariantMap MobileProviders::getCdmaInfo(const QString &provider)
         n = n.nextSibling();
     }
 
-    temp.insert("number", getCdmaNumber());
-    temp.insert("sidList", sidList);
+    temp.insert(QStringLiteral("number"), getCdmaNumber());
+    temp.insert(QStringLiteral("sidList"), sidList);
     return temp;
 }
 
@@ -382,7 +381,7 @@ QString MobileProviders::getNameByLocale(const QMap<QString, QString> &localized
         }
     }
 
-    name = localizedNames["en"];
+    name = localizedNames[QStringLiteral("en")];
 
     // Use any language if no proper localized name were found.
     if (name.isEmpty() && !localizedNames.isEmpty()) {
