@@ -26,7 +26,14 @@ class PLASMANM_EDITOR_EXPORT MobileProviders
 public:
     static const QString ProvidersFile;
 
-    enum ErrorCodes { Success, CountryCodesMissing, ProvidersMissing, ProvidersIsNull, ProvidersWrongFormat, ProvidersFormatNotSupported };
+    enum ErrorCodes {
+        Success,
+        CountryCodesMissing,
+        ProvidersMissing,
+        ProvidersIsNull,
+        ProvidersWrongFormat,
+        ProvidersFormatNotSupported,
+    };
 
     MobileProviders();
     ~MobileProviders();
