@@ -21,7 +21,12 @@ public:
     explicit WireGuardTabWidget(const NMVariantMapList &peerData, QWidget *parent = nullptr, Qt::WindowFlags f = {});
     ~WireGuardTabWidget() override;
 
-    enum EndPointValid { BothValid, AddressValid, PortValid, BothInvalid };
+    enum EndPointValid {
+        BothValid,
+        AddressValid,
+        PortValid,
+        BothInvalid
+    };
 
     void loadConfig(const NMVariantMapList &peerData);
 
