@@ -17,8 +17,16 @@ class PLASMANM_EDITOR_EXPORT SimpleIpListValidator : public QValidator
 {
     Q_OBJECT
 public:
-    enum AddressType { Ipv4, Ipv6, Both };
-    enum AddressStyle { Base, WithCidr, WithPort };
+    enum AddressType {
+        Ipv4,
+        Ipv6,
+        Both
+    };
+    enum AddressStyle {
+        Base,
+        WithCidr,
+        WithPort
+    };
 
     explicit SimpleIpListValidator(AddressStyle style = AddressStyle::Base, AddressType allow = AddressType::Both, QObject *parent = nullptr);
     ~SimpleIpListValidator() override;
