@@ -99,14 +99,8 @@ bool UiUtils::isConnectionTypeSupported(NetworkManager::ConnectionSettings::Conn
         return false;
     }
 
-    bool manageVirtualConnections = Configuration::self().manageVirtualConnections();
-
-    if (type == NetworkManager::ConnectionSettings::Bond //
-        || type == NetworkManager::ConnectionSettings::Bridge //
-        || type == NetworkManager::ConnectionSettings::Infiniband //
-        || type == NetworkManager::ConnectionSettings::Team //
-        || type == NetworkManager::ConnectionSettings::Vlan) {
-        return manageVirtualConnections;
+    if (isConnectionTypeVirtual(type)) {
+        return Configuration::self().manageVirtualConnections();
     }
 
     return true;
@@ -118,7 +112,8 @@ bool UiUtils::isConnectionTypeVirtual(NetworkManager::ConnectionSettings::Connec
         || type == NetworkManager::ConnectionSettings::Bridge //
         || type == NetworkManager::ConnectionSettings::Infiniband //
         || type == NetworkManager::ConnectionSettings::Team //
-        || type == NetworkManager::ConnectionSettings::Vlan) {
+        || type == NetworkManager::ConnectionSettings::Vlan //
+        || type == NetworkManager::ConnectionSettings::Loopback) {
         return true;
     }
 
@@ -171,6 +166,9 @@ QString UiUtils::interfaceTypeLabel(const NetworkManager::Device::Type type, con
             }
         }
     } break;
+    case NetworkManager::Device::Loopback:
+        deviceText = i18nc("title of the interface widget in nm's popup", "Loopback");
+        break;
     case NetworkManager::Device::Ethernet:
     default:
         deviceText = i18nc("title of the interface widget in nm's popup", "Wired Ethernet");
@@ -235,6 +233,9 @@ QString UiUtils::iconAndTitleForConnectionSettingsType(NetworkManager::Connectio
         text = i18n("WireGuard VPN");
         icon = QStringLiteral("network-vpn");
         break;
+    case ConnectionSettings::Loopback:
+        text = i18n("Loopback");
+        break;
     default:
         text = i18n("Unknown connection type");
         break;
@@ -268,6 +269,9 @@ QString UiUtils::prettyInterfaceName(NetworkManager::Device::Type type, const QS
     case NetworkManager::Device::Bridge:
         ret = i18n("Bridge (%1)", interfaceName);
         break;
+    case NetworkManager::Device::Loopback:
+        ret = i18n("Loopback Interface (%1)", interfaceName);
+        break;
     default:
         ret = interfaceName;
     }
@@ -610,6 +614,9 @@ QString UiUtils::labelFromWirelessSecurity(NetworkManager::WirelessSecurityType
     case NetworkManager::Wpa3SuiteB192:
         tip = i18nc("@label WPA3-EAP-SUITE-B-192 security", "WPA3-EAP-SUITE-B-192");
         break;
+    case NetworkManager::OWE:
+        tip = i18nc("@label OWE security", "Enhanced Open (OWE)");
+        break;
     default:
         tip = i18nc("@label unknown security", "Unknown security type");
         break;
