@@ -11,6 +11,7 @@
 
 class WireGuardKeyValidator : public QValidator
 {
+    Q_OBJECT
 public:
     explicit WireGuardKeyValidator(QObject *parent = nullptr);
     ~WireGuardKeyValidator() override;
@@ -18,7 +19,7 @@ public:
     QValidator::State validate(QString &, int &) const override;
 
 private:
-    QRegularExpressionValidator *m_validator;
+    QRegularExpressionValidator *const m_validator;
 };
 
 #endif // SIMPLEIPV4ADDRESSVALIDATOR_H
