@@ -21,13 +21,13 @@ class Q_DECL_EXPORT OpenVpnUiPlugin : public VpnUiPlugin
 public:
     explicit OpenVpnUiPlugin(QObject *parent = nullptr, const QVariantList & = QVariantList());
     ~OpenVpnUiPlugin() override;
-    SettingWidget *widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr) override;
-    SettingWidget *askUser(const NetworkManager::VpnSetting::Ptr &setting, const QStringList &hints, QWidget *parent = nullptr) override;
+    SettingWidget *widget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent) override;
+    SettingWidget *askUser(const NetworkManager::VpnSetting::Ptr &setting, const QStringList &hints, QWidget *parent) override;
 
     QString suggestedFileName(const NetworkManager::ConnectionSettings::Ptr &connection) const override;
-    QString supportedFileExtensions() const override;
-    NMVariantMapMap importConnectionSettings(const QString &fileName) override;
-    bool exportConnectionSettings(const NetworkManager::ConnectionSettings::Ptr &connection, const QString &fileName) override;
+    QStringList supportedFileExtensions() const override;
+    ImportResult importConnectionSettings(const QString &fileName) override;
+    ExportResult exportConnectionSettings(const NetworkManager::ConnectionSettings::Ptr &connection, const QString &fileName) override;
 
 private:
     QString saveFile(QTextStream &in, const QString &endTag, const QString &connectionName, const QString &fileName);
